(ns mailhead.visualize
  (:use [tangle.core])
  (:require [mailhead.parser :as parser]))

(defn edge-path [receive-path]
  (let [path (reverse receive-path)
        chain (concat (map :sender (butlast path)) [(:receiver (last path))])
        cleaned-chain (map clojure.string/lower-case chain)]
    (partition 2 (interleave cleaned-chain (rest cleaned-chain)))))

(defn edges [path]
  (let [p (map #(concat % [{:label "ms" :fillcolor "gray" :color "gray"}]) (edge-path path))]
    (into [] (map #(into [] %)) p)))

(defn draw-path [receive-path]
  (-> (graph->dot
       []
       (edges receive-path)
       {:node {:shape :box
               :fontname "Arial"
               :fontsize 12
               :style "filled"
               :fillcolor "darkgoldenrod1"
               :color "darkgoldenrod3"}
        :edge {:fontname "Arial"
               :fontsize 10}
        :directed? true
        :graph {:rankdir :LR
                :color "transparent"}})
      (dot->image "png")))

(defn draw [filename]
  (draw-path (parser/parse-from-file filename)))

(draw "/home/aaron/workbench/clojurecup2015/sample-data/header1.eml")

